==> kubernetes-model-extensions-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyPortFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NetworkPolicyPortFluentImpl<A extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>{
  public NetworkPolicyPortFluentImpl() {
  }
  public NetworkPolicyPortFluentImpl(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort instance) {
    this.withEndPort(instance.getEndPort()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer endPort;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder port;
  private java.lang.String protocol;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getEndPort() {
    return this.endPort;
  }
  public A withEndPort(java.lang.Integer endPort) {
    this.endPort=endPort; return (A) this;
  }
  public java.lang.Boolean hasEndPort() {
    return this.endPort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort() {
    return this.port!=null?this.port.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildPort() {
    return this.port!=null?this.port.build():null;
  }
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port) {
    _visitables.get("port").remove(this.port);
    if (port!=null){ this.port= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A withNewPort(java.lang.Integer intVal) {
    return (A)withPort(new IntOrString(intVal));
  }
  public A withNewPort(java.lang.String strVal) {
    return (A)withPort(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPort() {
    return new io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluentImpl.PortNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluentImpl.PortNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editPort() {
    return withNewPortLike(getPort());
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPort() {
    return withNewPortLike(getPort() != null ? getPort(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewPortLike(getPort() != null ? getPort(): item);
  }
  public java.lang.String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(java.lang.String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public java.lang.Boolean hasProtocol() {
    return this.protocol != null;
  }
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0) {
    return (A)withProtocol(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPolicyPortFluentImpl that = (NetworkPolicyPortFluentImpl) o;
    if (endPort != null ? !endPort.equals(that.endPort) :that.endPort != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (protocol != null ? !protocol.equals(that.protocol) :that.protocol != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(endPort,  port,  protocol,  additionalProperties,  super.hashCode());
  }
  public class PortNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>> implements io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PortNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    PortNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) NetworkPolicyPortFluentImpl.this.withPort(builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-extensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyPortFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NetworkPolicyPortFluentImpl<A extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>{
  public NetworkPolicyPortFluentImpl() {
  }
  public NetworkPolicyPortFluentImpl(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort instance) {
    this.withEndPort(instance.getEndPort()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer endPort;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder port;
  private java.lang.String protocol;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getEndPort() {
    return this.endPort;
  }
  public A withEndPort(java.lang.Integer endPort) {
    this.endPort=endPort; return (A) this;
  }
  public java.lang.Boolean hasEndPort() {
    return this.endPort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort() {
    return this.port!=null?this.port.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildPort() {
    return this.port!=null?this.port.build():null;
  }
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port) {
    _visitables.get("port").remove(this.port);
    if (port!=null){ this.port= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A withNewPort(java.lang.Integer intVal) {
    return (A)withPort(new IntOrString(intVal));
  }
  public A withNewPort(java.lang.String strVal) {
    return (A)withPort(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPort() {
    return new io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluentImpl.PortNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluentImpl.PortNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editPort() {
    return withNewPortLike(getPort());
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPort() {
    return withNewPortLike(getPort() != null ? getPort(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewPortLike(getPort() != null ? getPort(): item);
  }
  public java.lang.String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(java.lang.String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public java.lang.Boolean hasProtocol() {
    return this.protocol != null;
  }
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0) {
    return (A)withProtocol(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPolicyPortFluentImpl that = (NetworkPolicyPortFluentImpl) o;
    if (endPort != null ? !endPort.equals(that.endPort) :that.endPort != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (protocol != null ? !protocol.equals(that.protocol) :that.protocol != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(endPort,  port,  protocol,  additionalProperties,  super.hashCode());
  }
  public class PortNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>> implements io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PortNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    PortNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) NetworkPolicyPortFluentImpl.this.withPort(builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}
